aboutsummaryrefslogtreecommitdiff
path: root/plugins-scripts/check_disk_smb.pl
diff options
context:
space:
mode:
Diffstat (limited to 'plugins-scripts/check_disk_smb.pl')
-rwxr-xr-xplugins-scripts/check_disk_smb.pl6
1 files changed, 3 insertions, 3 deletions
diff --git a/plugins-scripts/check_disk_smb.pl b/plugins-scripts/check_disk_smb.pl
index 0c89db57..8b6cd2eb 100755
--- a/plugins-scripts/check_disk_smb.pl
+++ b/plugins-scripts/check_disk_smb.pl
@@ -3,7 +3,7 @@
#
# check_disk.pl <host> <share> <user> <pass> [warn] [critical] [port]
#
# Nagios host script to get the disk usage from a SMB share
#
# Changes and Modifications
# =========================
@@ -171,7 +171,7 @@ my $res = undef;
my $perfdata = "";
my @lines = undef;
# Just in case of problems, let's not hang Nagios
$SIG{'ALRM'} = sub {
print "No Answer from Client\n";
exit $ERRORS{"UNKNOWN"};
@@ -293,7 +293,7 @@ sub print_help () {
print_revision($PROGNAME,'@NP_VERSION@');
print "Copyright (c) 2000 Michael Anthon/Karl DeBisschop
-Perl Check SMB Disk plugin for Nagios
+Perl Check SMB Disk plugin for monitoring
";
print_usage();
@@ -3,7 +3,7 @@
# check_disk.pl <host> <share> <user> <pass> [warn] [critical] [port]
#
-# Nagios host script to get the disk usage from a SMB share
+# Monitoring host script to get the disk usage from a SMB share
#
# Changes and Modifications
@@ -171,7 +171,7 @@ my $res = undef;
my $perfdata = "";
my @lines = undef;
-# Just in case of problems, let's not hang Nagios
+# Just in case of problems, let's not hang the monitoring system
$SIG{'ALRM'} = sub {
print "No Answer from Client\n";